==> haskell-dav-1.3.4-756-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-IwWeqElYOXVBUOTYfSD5fk
key:                  DAV-1.3.4-IwWeqElYOXVBUOTYfSD5fk
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  8292474dd897cf685591ef6822ae71bb
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-IwWeqElYOXVBUOTYfSD5fk
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-client-0.7.18-163W4AHWMZxiWwErxEeuv
    http-client-tls-0.3.6.4-2oeYpKUjUcFHV14IdzgHEG
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    lens-5.2.3-GXFWsxB7RRtIGQiKpxuie1 mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-HqI64ofa1BLBo89Vn03fsg
    xml-hamlet-0.5.0.2-4JjNJoxQusJI9mEbsnUTIV

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-771-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-6GxLSNNcII7DFxC0aVSDed
key:                  DAV-1.3.4-6GxLSNNcII7DFxC0aVSDed
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  e06de3d8b47d1684b251866fe7a158ae
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-6GxLSNNcII7DFxC0aVSDed
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-IiC4W3ne2FhKO4v0Ko50kd containers-0.6.7
    data-default-0.7.1.1-86NXSPgvsmt76HSLrJaFnV exceptions-0.10.5
    http-client-0.7.18-459exqS5txS1OoId3JMPZk
    http-client-tls-0.3.6.4-7S2cUrl1lPP9SbVvzQv2U1
    http-types-0.12.4-GvCYNDYAmXh2LOy70F8sjw
    lens-5.3-8ZK9QDANmBT9CZTQ77OGiP mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-81seU10hWeHFdsy7CHhbZu
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-87Hhx57rvSR2PvSgKyGXyc
    xml-hamlet-0.5.0.2-HixgXLmy0q7GjGQeoqSCdh

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
